Header
======

Frame
-----

.. currentmodule:: fastobo.header
.. automodule:: fastobo.header


.. autoclass:: HeaderFrame(AbstractFrame)
   :members:


Clauses
-------

.. autoclass:: BaseHeaderClause(AbstractClause)
   :members:

.. autoclass:: FormatVersionClause(BaseHeaderClause)
   :members:

.. autoclass:: DataVersionClause(BaseHeaderClause)
   :members:

.. autoclass:: DateClause(BaseHeaderClause)
   :members:

.. autoclass:: SavedByClause(BaseHeaderClause)
   :members:

.. autoclass:: AutoGeneratedByClause(BaseHeaderClause)
   :members:

.. autoclass:: ImportClause(BaseHeaderClause)
   :members:

.. autoclass:: SubsetdefClause(BaseHeaderClause)
   :members:

.. autoclass:: SynonymTypedefClause(BaseHeaderClause)
   :members:

.. autoclass:: DefaultNamespaceClause(BaseHeaderClause)
   :members:

.. autoclass:: IdspaceClause(BaseHeaderClause)
   :members:

.. autoclass:: TreatXrefsAsEquivalentClause(BaseHeaderClause)
   :members:

.. autoclass:: TreatXrefsAsGenusDifferentiaClause(BaseHeaderClause)
   :members:

.. autoclass:: TreatXrefsAsReverseGenusDifferentiaClause(BaseHeaderClause)
   :members:

.. autoclass:: TreatXrefsAsRelationshipClause(BaseHeaderClause)
   :members:

.. autoclass:: TreatXrefsAsIsAClause(BaseHeaderClause)
   :members:

.. autoclass:: TreatXrefsAsHasSubclassClause(BaseHeaderClause)
   :members:

.. autoclass:: PropertyValueClause(BaseHeaderClause)
   :members:

.. autoclass:: RemarkClause(BaseHeaderClause)
   :members:

.. autoclass:: OntologyClause(BaseHeaderClause)
   :members:

.. autoclass:: OwlAxiomsClause(BaseHeaderClause)
   :members:

.. autoclass:: UnreservedClause(BaseHeaderClause)
   :members:
